#
# spec file for package glade
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname libgladeui-2-13

Name:           glade
Version:        3.40.0
Release:        4.2
Summary:        User Interface Builder for GTK+ 3
License:        GPL-2.0-or-later
Group:          Development/Tools/GUI Builders
URL:            https://glade.gnome.org/
Source0:        https://download.gnome.org/sources/glade/3.40/%{name}-%{version}.tar.xz
# PATCH-FIX-SLE glade-python3.patch mgorse@suse.com -- explicitly use python3.
Patch0:         glade-python3.patch

BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  meson >= 0.49.0
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gjs-1.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.64.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.10.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.8.0
# Disable webkitgtk catalog support - pulls in soup2
#BuildRequires:  pkgconfig(webkit2gtk-4.0) >= 2.28.0

%description
Glade is a RAD tool to develop user interfaces for the Gtk+ 3 toolkit
and the GNOME desktop environment.

%package -n %{soname}
Summary:        Core library of the GLADE User Interface Builder
Group:          System/Libraries

%description -n %{soname}
Glade is a RAD tool to develop user interfaces for the Gtk+ 3 toolkit
and the GNOME desktop environment.

%package -n typelib-1_0-Gladeui-2_0
Summary:        Introspection bindins for libgladeui
Group:          System/Libraries

%description -n typelib-1_0-Gladeui-2_0
Glade is a RAD tool to develop user interfaces for the Gtk+ 3 toolkit
and the GNOME desktop environment.

This package provides the GObject Introspection bindings for the
libgladeui library.

%package -n libgladeui-2-devel
Summary:        Development files for libgladeui
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}
Requires:       typelib-1_0-Gladeui-2_0 = %{version}
# The gtk-doc documentation is not parallel installable (bnc#646997)
Conflicts:      libgladeui-1-devel

%description -n libgladeui-2-devel
Glade is a RAD tool to develop user interfaces for the Gtk+ 3 toolkit
and the GNOME desktop environment.

This subpackage contains the header files for developing
applications that want to make use of libgladeui.

%package docs
Summary:        Documentation for GLADE User Interface Builder
BuildArch:      noarch

%description docs
Glade is a RAD tool to develop user interfaces for the Gtk+ 3 toolkit
and the GNOME desktop environment.

This package contains the documentation for Glade.

%lang_package

%prep
%setup -q
%if 0%{?sle_version} && 0%{?sle_version} < 160000
%patch -P 0 -p1
%endif

%build
%meson \
	-D gtk_doc=true \
	-D webkit2gtk=disabled \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%ldconfig_scriptlets -n %{soname}

%files
%license COPYING COPYING.GPL COPYING.LGPL
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/glade
%{_bindir}/glade-previewer
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Glade.appdata.xml
%{_datadir}/applications/org.gnome.Glade.desktop
%{_datadir}/glade/
%{_datadir}/gettext/its/glade-catalog.its
%{_datadir}/gettext/its/glade-catalog.loc
%{_datadir}/icons/hicolor/*/apps/*.*
%{_libdir}/glade/modules/libgladegjs.so
%{_libdir}/glade/modules/libgladegtk.so
%{_libdir}/glade/modules/libgladepython.so
# Disable webkitgtk catalog support - pulls in soup2
#%%{_libdir}/glade/modules/libgladewebkit2gtk.so
%{_mandir}/man1/glade-previewer.1%{?ext_man}
%{_mandir}/man1/glade.1%{?ext_man}

%files -n %{soname}
%{_libdir}/libgladeui*.so.*
# These directories are needed by third-party catalogs, and are explicitly
# referenced in the pkg-config file, so it makes sense to own them here
%dir %{_datadir}/glade
%dir %{_datadir}/glade/catalogs
%dir %{_datadir}/glade/pixmaps
%dir %{_datadir}/glade/pixmaps/hicolor
%dir %{_datadir}/glade/pixmaps/hicolor/*
%dir %{_datadir}/glade/pixmaps/hicolor/*/actions
%dir %{_libdir}/glade
%dir %{_libdir}/glade/modules

%files -n typelib-1_0-Gladeui-2_0
%{_libdir}/girepository-1.0/Gladeui-2.0.typelib

%files -n libgladeui-2-devel
%doc AUTHORS TODO
%{_includedir}/libgladeui-2.0/
%{_libdir}/pkgconfig/gladeui-2.0.pc
%{_libdir}/libgladeui*.so
%{_datadir}/gir-1.0/*.gir

%files lang -f %{name}.lang

%files docs
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/gladeui-2

%changelog
* Tue Feb 20 2024 Michael Gorse <mgorse@suse.com>
- Add glade-python3.patch for SLE. Pass python3 to the meson
  python module, to avoid pulling in python 3.11.
* Wed Sep 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Disable webkitgtk catalog support, as it pulls in soup2. Disable
  pkgconfig(webkit2gtk-4.0) BuildRequires and pass
  webkit2gtk=disabled to meson.
* Thu Aug 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.40.0:
  + Remove survey
  + Add user manual menu item
  + 'Clear' action in "Setup Text Attributes" dialog now clears
    only selected attributes
  + Fix Segfault in gnome-builder when widget doesn't have a name
  + Fix build against Python 3.9
  + Bugs fixed: glgo#GNOME/glade#502, glgo#GNOME/glade#499,
    glgo#GNOME/glade#509, glgo#GNOME/glade#373,
    glgo#GNOME/glade#484, glgo#GNOME/glade#194,
    glgo#GNOME/glade#53, glgo#GNOME/glade#98, glgo#GNOME/glade#491.
    (CVE-2020-36774 bsc#1220059).
- Package docs sub-package as noarch.
- Drop patches fixed upstream:
  + 117.patch
  + 9db1fba1fa93905c9169c1e29049e4b2f6337c39.patch
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 117.patch: Fix build with meson 0.61.0 and newer.
* Fri Dec 10 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add pkgconfig(gjs-1.0) BuildRequires: Build gjs widgets support,
  and stop passing gjs=disabled to meson.
- Add 9db1fba1fa93905c9169c1e29049e4b2f6337c39.patch: GladeProject:
  Segfault in gnome-builder when widget doesn't have a name.
- Split out new sub package for docs.
- Use ldconfig_scriptlets macro for post(un) ldconfig handling.
* Fri Nov 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Fix windows compatibility issues.
  + Fix build against Python 3.9.
  + Bugs fixed: glgo#GNOME/glade#355, glgo#GNOME/glade#53,
    glgo#GNOME/glade#371.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Fix issue #471: "XML not updated after adding element".
  + Fix issue #480: "version field not always updated in XML".
  + Fix issue #474: "GtkLabel: setup text attribute issues".
  + Fix issue #479: "Glade 3.36.0 segfaults when opening a file".
  + Fix issue pasting widget with ctrl+v in GtkGrid.
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Load template files as new GTypes and add them to "User
    templates" widget group automatically without the need of a
    catalog.
  + Added JavaScript widget support.
  + Use version data from gir to improve deprecation/target tests.
  + Implement survey using new backend at surveys.gnome.org.
  + Keep survey state in config file.
  + Associate with application/x-gtk-builder.
  + Project properties dialog improvements.
  + Improve toolkit target version selection in project properties
    dialog.
  + Improve treemodel char data type handling.
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.0:
  + Build: Remove autotools.
  + Plugins: Added GJS plugin for JavaScript objects support.
  + Issue #433: Implement survey using new backend at
    surveys.gnome.org.
  + Ignore locale when saving numeric values.
  + Associate application/x-gtk-builder with glade's .desktop file.
  + Plugins: Added GJS plugin for JavaScript objects support.
  + gtk: Add GtkScrolledWindow propagate-natural-width property.
  + GladeScrolledWindowEditor: Squeeze width/height properties in
    two columns.
  + Webkit2gtk plugin: add missing displayable values and sandbox
    web view.
  + dtd: Make init-function an element, not an attribute.
- Port to meson build system:
  + Add meson BuildRequires.
  + Replace configure/make/make_install with
    meson/meson_build/meson_install.
* Thu May  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Add GDK_VERSION_MIN_REQUIRED
  + Adding "Glade" to "About" section.
  + Add initial implementation of Automatic Templates
  + Add initial support for GFile type properties
  + Add metadata information about releases
  + Add OARS tags
  + Add translator comments to the .desktop file
  + Allow to specify placeholder to GtkListBox
  + Allow to use GtkFileChooserNative
  + Appdata: update app-id
  + build:
  - Do not use a system variable only for Windows
  - Fix OSX support in meson
  - Port to meson build system
  - Remove G_CONST_RETURN usage
  + Bump Gtk required version to 3.22
  + Couple of fixes for memory leaks found with valgrind
  + Create GladeSettings to hold the settings instead of using a
    Gtk widget for holding it
  + dnd: Enable Drag&Drop on wayland
  + doc:
  - Modernize the documentation
  - Remove missing xml files
  - Make some changes to fix warnings with the documentation
  + dtd: Add several new elements
  + Fix loading dylibs on OSX
  + Fix on debug traces after rename GladePropertyClass to
    GladePropertyDef
  + Fix several compiler warnings
  + Fix split sentense in GladeProject
  + Fix tab/space identation
  + Fix two memory leaks discovered with valgrind
  + Fix xgettext string extraction for catalogs
  + flatpak: Set meson as buildsystem
  + GladeAdaptorChooser: add missing translation domain
  + GladeCommand:
  - Ensure widget name on object properties
  - Ignore special child types placeholders in add command.
  + GladeGtkWindow: mark titlebar placeholder as special child
    type.
  + GladeEditor: expose signal editor widget as a property
  + GladeEditorProperty, GladePropertyClass, GladeWidgetAdaptor:
  + GladeEPropAttrs: use sane adjustment values for size and scale
    attrs
  + GladeEPropNumeric: bind precision property to spin button
  + GladeGtkAdjustment: add digits virtual property
  + GladeGtkBin: add initial support for GtkBin abstract class
  + GladeGtkBox: improve children sort function
  + GladeGtkDialog: chain up post_create() method
  + GladeGtkHeaderBar:
  - Improve position packing property handling
  - Mark title and subtitle as translatable
  + GladeGtkWidget: save accessible-role atk property
  + GladeGtkWindow:
  - Fix regression in csd handling
  - Remove get_children() method
  + GladeImageItemEditor: use display name for commands names
  + GladeIntro:
  - Fix regresion in find_widget_forall()
  - Use name and buildable name to find widgets
  + GladeModelButton:
  - Enable icon/iconic properties
  - Improve editor
  + GladePopup: Clear add item when adding as toplevel
  + GladeProject:
  - Add handler signals
  - Escape markup in parser errors
  + GladeProperty:
  - Add precision property
  - Keep the bind-source, bind-property and bind-flags elements
  + GladePropertyClass: round floating point values to epsilon
  + GladeSignalClass: rename glade_signal_class_get_type
  + GladeSignalDef: fix documentation for
    glade_signal_def_set_deprecated
  + gladeui-2.0.pc: Data paths relative to datadir
  + gladeui:
  - Change the boolean parsing logic to be the same as Gtk
  - Ensure that we write the "type-func" property when a
    get-type-function is defined in the catalog
  - Fix crash on drag-n-drop
  - Fix GIR package reference and add c-include
  - Fix leak of create_type in GladePropertyClass
  - Fix memory leak in GWActionClass
  - Fix several memory leaks with GladeWidgetAdaptor
  - Fix several tiny memory leaks found with valgrind
  - Fix wrong pointer convertion in GladeDesignView
  - ignore various GParameter deprecations
  - Modernize GladeSignalEditor codebase
  - Modernize GladeWidgetAdaptor definition
  - Plug tiny leak on Drag & Drop
  - remove implicit cast in assignment
  - remove unused type_func variable
  - Replace the last occurences of GladeWidgetClass with
    GladeWidgetAdaptor in the comments
  - Use G_DECLARE_DERIVABLE_TYPE for GladeAdaptorChooserWidget
  - Use G_DECLARE_DERIVABLE_TYPE for GladeApp
  - Use G_DECLARE_DERIVABLE_TYPE for GladeBaseEditor
  - Use G_DECLARE_DERIVABLE_TYPE for GladeCellRendererIcon
  - Use G_DECLARE_DERIVABLE_TYPE for GladeClipboard
  - Use G_DECLARE_DERIVABLE_TYPE for GladeCommand
  - Use G_DECLARE_DERIVABLE_TYPE for GladeDesignLayout
  - Use G_DECLARE_DERIVABLE_TYPE for GladeDesignView
  - Use G_DECLARE_DERIVABLE_TYPE for GladeEditor
  - Use G_DECLARE_DERIVABLE_TYPE for GladeEditorProperty
  - Use G_DECLARE_DERIVABLE_TYPE for GladeEditorSkeleton
  - Use G_DECLARE_DERIVABLE_TYPE for GladeEditorTable
  - Use G_DECLARE_DERIVABLE_TYPE for GladeInspector
  - Use G_DECLARE_DERIVABLE_TYPE for GladeNamedIconChooserDialog
  - Use G_DECLARE_FINAL_TYPE for GladeObjectStub
  - Use G_DECLARE_INTERFACE for GladeDrag
  - Use G_DECLARE_INTERFACE for GladeEditable
  + GladeWidgetAdaptor:
  - added deprecated-since metadata
  - add glade_widget_adaptor_get_display_name()
  + GladeWidget: add support for abstract classes
  + GladeWindow:
  - move actions to GtkApplication
  - port to GtkApplication
  - simplify pointer mode actions
  + GtkActionable: add action-target property
  + gtk+:
  - Add deprecated flag to GtkButton and GtkImage stock
    properties
  - Add homogeneous property to GtkStackSwitcher
  - Add missing 3.22 enum/flag values
  - Allow to use GtkResponseType with GtkDialog and GtkInfobar
    buttons
  - Keep internationalization context in Atk properties
  - properly cast to avoid warnings
  - Provide Gtk 3.22 properties for GtkScrolledWindow
  - workaround truncation warning by being safer
  + Gtk Catalog:
  - add back GtkStatusbar
  - mark GtkImageMenuItem as deprecated since 3.10
  + GtkImage: Fix icon size being reset
  + GtkLinkButton: allow to edit the label
  + Gtk plugin: add support for GFileIcon
  + i18n: Do not use input file for not translated files
  + icon: update app icon
  + introspection: Add many annotations to sources
  + Make it easier to track GladeXML elements and be GObject
    Introspection friendly by registering boxed types
  + meson: Activate enable-debug variables
  + Migrate from intltool to gettext
  + No wide handles in `center_paned` and `left_paned`
  + Prevent dragging an ancestor inside a child
  + RDNN appdata & desktop file
  + Remove GladeInstantiable prefix from UI
  + Rename GladePropertyClass to GladePropertyDef and declare it as
    boxed
  + Rename GladeSignalClass to GladeSignalDef and declare it as
    boxed
  + Rename GWActionClass to GladeWidgetActionDef to use the right
    namespace
  + Rename *Klass to *Class as there are no name collision anymore
  + Replace some functions by Gtk 3.22 ones
  + Respect the Glade namespace for macros and defines
  + Set the "About Dialogue" as modal
  + snap: update for icon filename changes
  + Stop defaulting missing images to deprecated stock icons
  + tests: Include back GtkTreeViewColumn
  + ui/widget: Make template ver# warning more useful
  + Update FSF address
  + Use autoreconf instead deprecated gnome-common
  + Utils: get the absolute path but avoid accessing it
  + widget: canonicalize support-warning property name
  + widget-editor: Replace margin right/left for end/start
- Add define soname libgladeui-2-12, and rename subpackage
  following upstreams soname bump/change.
* Wed Feb 26 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.22.2:
  + Canonicalize support-warning property name.
  + Add snap packaging.
  + GladeCommand: ignore special child types placeholders in add
    command.
  + GladeGtkWindow: mark titlebar placeholder as special child
    type.
  + Fix bug "Glade deletes all widgets when adding a Scrolled
    Window parent, but doesn't show it."
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Jan  8 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Migrate to python3:
  + Replace python-devel BuildRequires with python3-devel.
  + Pass PYTHON=python3 to configure.
* Thu Apr  5 2018 luc14n0@linuxmail.org
- Update to version 3.22.1:
  + Fixes:
  - Glade always re-enables the client-side-decoration option
    (bgo#794492);
  - Does not write the accessible-role accessibility property
    (bgo#794518);
  - Glade does not allow ApplicationWindow's title to be marked
    as translatable" (bgo#782753);
  - GtkDialog CSD support.
- Drop update-desktop-files BuildRequires and suse_update_desktop_\
  file: they are no longer needed.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.22.0:
  + bgo#774994: "in treeview columns editor contextual menu does
    nothing"
  + Simplified GladeBaseEditor
  + Fix formatting / layout of project verification details.
  + Widge chooser: activate treeview with single click and enable
    Drag & Drop.
  + Fix Design view selected state.
  + bgo#793036: "GtkCellRenderer Properties not loaded from glade
    file".
  + Fix bug in action widgets response-id parsing on 32bits system.
  + bgo#772485: "File Name property of GtkImage is copied to all
    other GtkImage"
  + GladeProject: always treat resource properties as relative.
  + bgo#793652: "Crash when deleting a list".
  + bgo#793757: "Gtk-CRITICAL **: _gtk_window_add_popover:
    assertion '_gtk_widget_get_parent (popover) == NULL' failed".
  + Add GDK_SUPER_MASK accelerator handling.
  + bgo#778537: "ActionBar need placeholder".
  + bgo#794141: Gtk.IconView disappeared from glade.
  + Updated translations.
* Mon Mar  5 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Mar  5 2018 luc14n0@linuxmail.org
- Update to version 3.21.0:
  + Main window UI overhaul.
  + An enhanced enum integer editor.
  + Added GtkGLArea object to gtk+ catalog.
  + Initial support for WebKit2GTK+ library.
  + Add GtkStackSidebar to control and display widget group.
  + Bug fixes:
  - "Please don't list 'Taiwan' as 'Taiwan, Province of China' in
    the country list" (bgo#767812).
  - Use correct tag when referring to Palette (bgo#763188).
  - Fix typo in translatable string; fixing old bgo#746531.
- Add pkgconfig(webkit2gtk-4.0) BuildRequires as a new dependency.
* Sun Mar  4 2018 bjorn.lie@gmail.com
- Update to version 3.20.4:
  + Fix bgo#772485: File Name property of GtkImage is copied to all
    other GtkImage.
  + Fix bgo#793652: Crash when deleting a list.
  + Fix bgo#793757: Gtk-CRITICAL **: _gtk_window_add_popover:
    assertion '_gtk_widget_get_parent (popover) == NULL' failed.
  + Add GDK_SUPER_MASK accelerator handling.
* Fri Mar  2 2018 antoine.belvire@opensuse.org
- Update to version 3.20.3.
  + Fix bgo#793036: "GtkCellRenderer Properties not loaded from
    glade file".
  + Add GtkStackSidebar to the toolbox.
  + Fix bgo#774994: "In treeview columns editor contextual menu
    does nothing".
  + GladeDesignView: set selected layout state.
* Mon Nov 27 2017 luc14n0@linuxmail.org
- Update to version 3.20.2:
  + Install appstream metadata to non-deprecated location.
  + Bug fixes:
  - Glade interface designer eating ram & cpu (bgo#763624).
  - Glade saves invalid GtkBuilder XML (bgo#790452).
  - GtkLabel xalign and halign appeared in GTK+ 3.16 and are not
    deprecated (bgo#782645).
  - Add background class to GladeDesignLayout children
    (bgo#773669).
  + Updated translations.
- Add gmodule-export-2.0 and gobject-2.0 pkgconfig BuildRequires:
  they were being pulled and used since the package already had
  another declared module dependencies upon glib2-devel, the same
  provider. Note that gobject-2.0 is not mentioned in configure.ac
  but it is checked by configure and the same goes for glib-2.0
  module.
- Drop docbook-xsl-stylesheets BuildRequires and add gtk-doc:
  that's what upstream uses and we don't want deviations to avoid
  unexpected bugs.
- Pass enable-man-pages enable-gtk-doc and to ensure that manuals
  and documentation will be built.
- Remove gnome-common BuildRequires and autogen.sh call, as we no
  longer carry any patches.
- Adopt %%make_build macro and drop raw commands following the best
  practices.
* Tue Oct  3 2017 luc14n0@linuxmail.org
- Update to version 3.20.1:
  + Fixes:
  - Glib g_ptr_array_find() name clash.
  - Survey css matching error on CSD.
  - "format not a string literal" warnings.
  + Bug fixes:
  - "GLADE 3.20: crash on changing ToolItem type" (bgo#773997).
  - "Using Spacebar to change menu selction causes crash"
    (bgo#765562).
  - "client side decoration, no space to add header bar"
    (bgo#765885).
  - Clicking in ... swap order of accelerators (bgo#589306).
  - "[Wayland] glade previewer is resizing windows until it
    crashes gnome-shell" (bgo#761651).
- Drop %%desktop_database_* and %%icon_theme_cache_* post/postun:
  functionality now covered by file triggers.
- Drop glade-use-g_ptr_array_find-from-GLib.patch: fixed upstream
  (bgo#782161).
* Sun Sep 10 2017 jengelh@inai.de
- Remove redundant %%clean section, and the no-op --with-pic.
- Ensure neutrality of descriptions. Trim/update descriptions.
* Wed May 31 2017 zaitor@opensuse.org
- Add glade-use-g_ptr_array_find-from-GLib.patch and add explicit
  pkgconfig(glib-2.0) BuildRequires: Fix build with new glib, patch
  from upstream git (bgo#782161).
- Following the above, add gnome-common BuildRequires and pass
  NOCONFIGURE=1 autogen.sh, as the above patch touches the
  buildsystem.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop glade-bgo702314.patch and glade-bgo721098-anjuta-hang.patch:
  Fixed upstream.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Workspace layout: render frame and selection box with CSS.
  + GtkWindow: don't set the same titlebar multiple times.
  + Integrate new properties in editor for GtkLabel, GtkTextView,
    GtkPopover, GtkStackSwitcher.
  + Support id-less builder files.
  + Added missing tags to the AppData file.
  + Added support for GtkActionBar and GtkFlowBox.
  + Main UI frontend: Use wide paned handles.
  + Fixed warning about imbalanced children in GtkNotebook support.
  + Added support for GtkPopoverMenu and GtkModelButton.
  + Added support for GtkPopover (bgo#740104).
  + Added <kudos> section to appdata.
  + Added missing displayable values (bgo#758290, bgo#758289,
    bgo#758288, bgo#758287).
  + Deprecate GtkAction, GtkActivatable, and friends (bgo#757609).
  + Avoid GTK+ style context warnings (bgo#758296, bgo#758297,
    bgo#758299, bgo#758300).
  + Drop deprecated style properties in GladeCloseButton
    (bgo#758280).
  + Replace use of deprecated gdk_cursor_new.
  + Add "Stack" to "Add parent" menu (bgo#754030).
  + Bugs fixed: bgo#430445, bgo#536840, bgo#741923, bgo#750985,
    bgo#751234, bgo#754131, bgo#759395, bgo#759455, bgo#759847,
    bgo#759872, bgo#760610, bgo#761839.
  + Updated translations.
* Sat Jun 20 2015 zaitor@opensuse.org
- Update to version 3.19.0:
  + bgo#732328: "New: add python3 support".
  + Added new symbolic variant of the app icon (bgo#747024).
  + bgo#741165: "Previewer crashes when taking PNG screenshot".
  + Added GtkSidebarWidget support.
  + Added GtkStack and GtkStackSwitcher support (bgo#738480).
  + Added GtkHeaderBar support (bgo#700914).
  + Improved undo/redo command list handling.
  + Added GtkBox center-widget support (bgo#738473).
  + Added GtkSearchBar support (bgo#738493).
  + Support CSD windows (bgo#700914).
  + Use current gtk-mac-integration API (bgo#738339).
  + Fixed bgo#732575: "Changed the type hint on the "Edit
    Separately" window to 'utility'".
  + Fixed bug "Missing plural form for UI string: emited %%d
    time(s)".
  + Avoid reading freed data in glade_project_read_requires.
  + Added class chooser popover to workspace (bgo#708146).
  + Added GThemedIcon support.
  + GladePreviewer: show handler information in infobar when a
    signal is emited.
  + Migrated UI from stock icons to icon names.
  + Seal needed deprecated API and replaced deprecared API.
  + GladeWindow: only show found recent files.
  + Added GtkLockButton support.
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 3.18.3:
  + Fixed property editor focus lost bug with construct-only
    properties.
  + GladePreviewer: Fixed bug previewing templates.
  + Bugs fixed: bgo#353002, bgo#728348, bgo#726410, bgo#727914,
    bgo#728377.
* Mon Jun 30 2014 dimstar@opensuse.org
- Update Summaries and descriptions to mention this version of
  Glade targets GTK+ 3.x.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.18.2:
  + Added dialog at start up to advertise user survey (bgo#726800).
  + Fixed "Editing UI and saving does not remove deleted Combo with
    Entry" (bgo#727992).
  + Fixed "Property Editor / Common tab: width & height request
    checkboxes have no effect" (bgo#364064).
* Thu Mar 27 2014 mgorse@suse.com
- Add glade-bgo702314.patch: properly fix cancelling an Add Parent
  action.
- Add glade-bgo721098-anjuta-hang.patch: Fix Anjuta hang when
  opening a project.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.18.1:
  + bgo#727014: "32 bit builds fail with -Werror=format-security".
  + GtkDialog: disabled use-header-bar property untill Glade
    supports GtkHeaderBar.
  + Fixed bug in numeric property editors (Box size).
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.18.0:
  + Added License property to Glade project.
  + Added realtime preview for custom CSS.
  + Added support for previewing templates.
  + glade-previewer added --slideshow option.
  + pango attribute editor: don't write on cancel for
    color/font.
  + Sort object dependancy before saving using a topological
    sorting algorithm.
  + Fixed <requires> tag output.
  + Fixed cellrenderer model column combobox chooser.
  + Fixed issue with numeric property editors.
  + Restored shortcuts function in workspace.
  + Added new jhbuild based bundling system for 64bit linux
    bundles.
  + gladeui: fix a pair of printf security problems.
  + Added Registration & User Survey Dialog in Help menu.
  + GtkGrid: Don't save width/height at their default values.
  + Bugs fixed: bgo#723819, bgo#721098, bgo#720585, bgo#709609,
    bgo#711858, bgo#702314, bgo#711568, bgo#712289.
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fixed bgo#702314 "Cancelling an Add Parent action is
    destructive".
  + pango attribute editor: don't write on cancel for color/font.
  + Fixed _glade_dnd_dest_set() crash (bgo#711568).
  + Report parsing error when loading a project (bgo#712289).
  + Sort object dependancy before saving using a topological
    sorting algorithm (bgo#709609 and bgo#711858).
  + Fixed bug in GtkScrolledWindow editor, vertical adjustmet was
    refering to the wrong property.
  + Fixed bgo#711863 'Remove "Generated with glade" XML comment'.
  + Fixed <requires> tag output.
  + Fixed regresion infering GtkBox virtual size property at load.
  + Fixed cellrenderer model column combobox chooser.
  + Fix input issues with numeric property editors.
  + Fixed Glade shortcuts like Delete by disabling keybindings used
    by shortcuts in every widget in the workspace. Now it is
    possible to delete a selected GtkEntry.
  + Fixed bugs in the inspector exposed by D&D by implementing
    GladeProject GtkTreeModelIface with a GtkTreeStore proxy
    object.
  + Fix order of customized property output (bgo#720585).
  + Updated translations.
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 3.16.0:
  + Added AppData for gnome-software to pick up glade (bgo#708641).
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.15.4:
  + Fixed bug when copying a button with custom content.
  + Added workaround for bgo#625867 "RadioButton information lost
    on cut+paste, add/remove parent, etc".
  + Fixes bug that prevented the runtime object to show the right
    pixbuf when copying a GtkImage.
  + bgo#679079: "Glade changes the "homogenous" packing property of
    toolbar buttons to "yes".
  + Improved pango text integer attributes editors. This should be
    enough to fix bgo#679006.
  + bgo#643923: "Should not use markup for GtkFrame's label".
  + bgo#584381: "Saving as an existing file name except the
    extension overwrites without confirmation.".
  + bgo#652655: "Setting entry on combobox moves the widget".
  + bgo#706304: "Python plugin broken by over-zealous version
    check" Bumped pygobject version to 3.8.0.
  + Fixed regresion that prevented loading extra catalog path at
    init time.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.15.3:
  + Add man pages (bgo#703013).
  + Double click on a toplevel border select the widget even if
    there is a child selected.
  + Support document level comments present before the root
    element.
  + Save glade version used to create the file in a comment.
  + Add GtkRevealer to the Gtk+ catalog.
  + Add GtkListBox support.
  + Added GtkOverlay support.
  + Improved Drag&Drop support, made inspector a drag source.
  + Added GtkApplicationWindow basic support.
  + Added GtkSearchEntry icons.
  + Bugs fixed: bgo#700730, bgo#706832, bgo#707173, bgo#703621.
- Add docbook-xsl-stylesheets BuildRequries: dependency to build
  the man pages.
- Rename libgladeui-2-4 subpackage to libgladeui-2-6, following
  upstreams soname change.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.15.2:
  + Add GtkPlacesSidebar to GTK+ catalog.
  + New icon for GtkMenuButton.
  + GTK+ catalog version now bumped to 3.10, include new
    translatable enumeration values and updated new versions and
    deprecations.
  + Added --enable-debug option and some debug flags to be set with
    GLADE_DEBUG environment variable.
  + Enable word wrapping in combo boxes (used to edit enumeration
    properties).
  + Split up the GTK+ plugin into mini source files, each one
    implementing it's own widget adaptor code (instead of one huge
    glade-gtk.c file).
  + Fix GtkIconFactory sources editor.
  + Allow setting the "id" attributes of items set in a
    GtkComboBoxText.
  + Avoid calling gtk_stock_list_ids() when
    gdk_display_get_default() is NULL, allows GIRs to build on
    some build machines.
  + Avoid updating the inspector treeview if the same project is
    set twice.
  + Escape key cancels a query dialog instead of approves creation
    of the new widget.
  + Many minor bugs and random crasher bugs also fixed.
  + Alsmost all widget types have their own custom editors now.
- Changes from version 3.15.1:
  + Much UI fixing and refactoring.
  + Added new --css and --screenshot options to glade-preview.
  + Fix main window shortcuts (bgo#695866).
  + Implemented Project Properties dialog with Glade as a composite
    tempalte.
  + Support editing the GtkWidget:name property (useful for CSS
    theming).
  + Improved project inter-widget dependancy calculation and
    project serialization ordering, object output ordering (and
    signal ordering) is now consistent and sorted.
  + GtkButton: response-id for dialogs is now optional (allowing
    adding dialog buttons that have no dialog response).
  + GtkImage: Support the new "resource" property.
  + GTK+ catalog updated to cover widgets in GTK+ 3.8.
  + Now show warnings in the UI for deprecated properties and
    signals.
  + Now show warnings in the Inspector view if any deprecated
    widgets, signals or properties are used (or if anything is used
    which is not available in the project's target version).
  + Optional properties are now always saved if they are enabled,
    allowing to explicitly set them to the default value (eg.
    GtkWidget:hexpand/vexpand).
  + Inspector search entry: Restore completions to work nicely
    again and filter the treeview with a search-in-text algorithm.
  + Inspector: Add a feature to expand-all.
  + Property editor title-bar is now optional in the View menu.
  + Fixed many deprecation warnings in Glade's compile.
  + Added Glade's first 2 ever unit tests.
  + Fixed Devhelp doc search for properties.
  + Make Drag'n'Drop work on regular clicks without entering Drag
    Mode and restored old Drag/Resize functionality when SHIFT is
    pressed.
  + Improved Drag/Resize which has been rather broken for a while.
  + Added Autosave and Automatic backup of previous file features,
    configurable in Glade's preferences Dialog.
  + Support Composite GtkBuilder template editing (mark a toplevel
    GtkWidget as the "composite template" widget in the Project
    Properties dialog or property editor).
  + Support editing of the project domain in the project properties
    dialog.
  + Properties in the Project Properties dialog are now undoable.
  + GladeSignalEditor: Automatically expand rows which have signal
    callbacks assigned when loading a widget.
  + Add options to decide what types of warnings should be
    presented at project save time, configurable in Glade's
    preferences dialog.
  + Added new property editor components GladePropertyLabel,
    GladePropertyShell and GladeEditorSkeleton, allowing us to
    create custom property editors using Glade.
  + Add "Grid" option to "Add parent" menu.
  + Added Gladeui catalog for IDE's and embedders to design Glade
    frontends with Glade.
  + Added private catalog to allow the GTK+ plugin to embed editors
    that it provides.
  + Added new GladeEpropCheck boolean property editor, to be used
    in some cases for boolean properties.
  + Added new adaptor methods
    GladeWidgetAdaptor->write_widget_after() and
    GladeWidgetAdaptor->destroy_object().
  + Automatically generate gladeui's enum types with glib-mkenums.
  + Modified properties now show up in italic letering instead of
    bold, bold lettering is reserved for title labels in custom
    property editors.
  + New components that now use GtkBuilder Composite Templates (and
    have had a basic review and rework of their UIs):
    GladePreferences (Glade's preferences dialog), GladeEditor
    (the property editor), GladeProjectProperties (the project
    properties dialog) and custom property editors:
    GladeActivatableEditor, GladeButtonEditor, GladeEntryEditor,
    GladeImageEditor, GladeLabelEditor, GladeWidgetEditor.
  + And many various bugfixes and UI fixes.
* Thu Mar  7 2013 dimstar@opensuse.org
- Update to version 3.15.0:
  + Added Drag&Drop support from the palette and within the
    workspace.
  + Added GtkLevelBar support.
  + Property editor UI cleanup.
  + Bugs fixed: bgo#685265, bgo#688326.
* Tue Feb 26 2013 zaitor@opensuse.org
- Add pkgconfig(gmodule-2.0) BuildRequires: configure checks for it
- Stop passing obsolete --disable-scrollkeeper to configure.
* Tue Nov 27 2012 dimstar@opensuse.org
- Update to version 3.14.2:
  + Fixed bgo#685816 "Widget attributes editing broken" by
    reverting old fix and setting use-action-appearance default
    back to false so the old sensitivity code can work as ussual.
  + Fixed bgo#678922 "When editing a label, the cursor is moved to
    the end after every change."
  + Fixed a few leak since glade_property_make_string() returns a
    newlly allocated string.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fixed bug in GtkButton custom editor properties sensitivity
    (bgo#685816).
  + Render bg in GladeDesignLayout and GladeDesignView.
  + Removed use of custon style providers. Fixes color problems in
    adwaita themes.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated GtkAssistant support (bgo#664276)
  + Set new property accel-group on action groups to make menu item
    accel work properly (bgo#684041)
  + Do not abort if a project has a uninstantiable or abstract
    class object instead load it as an object stub and let the user
    decide what to do (bgo#646259)
  + Fixed runtime warning on GladeBaseEditor and GladeSignalEditor
    dispose methods
  + Do not explicit set window bg as it should be handled by gtk.
  + Sync close-button with the original gedit widget.
  + Use new documentation infrastructure
  + Added load/save/edit support for <style> <class name="foo"/>
    </style>, (bgo#658035)
  + "Use Action Appearance not supported for GTK 2.12 but added to
    widgets in Glade 3.8.2" (bgo#679589)
  + Added glade_displayable_value_set_disabled() functions to
    disable GdkModifierType reserved values
  + Added build/mingw-w64 directory with script to cross compile
    and create windows installer using nsis
  + Fixes bug #675977 "Don't hard-code library search paths"
  + And many others cleanups and fixes
  + Bugs fixed: #679487, bgo#679721
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
- Rename libgladeui-2-0 to libgladeui-2-4, following upstreams
  soname bump.
* Sat May 12 2012 zaitor@opensuse.org
- Update to version 3.13.0:
  + Implemented Glade UI in glade.
  + Implemented GladePreferences dialog (bgo#588981).
  + Replaced deprecated font and color selection dialogs with font
    and color chooser dialogs.
  + Added GladeSignalEditor::detail-suggestions signal
  + Updated translations.
* Mon May  7 2012 dimstar@opensuse.org
- Update to version 3.12.1:
  + Use glade_util_get_placeholder_from_pointer() in paste action
    activate.
  + Added custom style provider to setup GladeDesignView and
    GladeDesignLayout background color to @base_color.
  + Fixed memory leak on GladeSignalEditor::callback-suggestions
    emison.
  + bgo#675395: Using right click to add a widget over a
    placeholder do not work as expected every time.
  + bgo#675042: plugins/gtk+.xml.in: always store GtkButton
    [x|y]align properties.
  + Removed use of lots of deprecated functions.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 3.12.0:
  + New features:
  - Implement callback name suggestion on glade-signal-editor
    (bgo#667570)
  - Emit a signal to notify signal activation (bgo#669272)
  + Other bugs fixed: bgo#645340, bgo#646366, bgo#664912.
- Drop glade-sig-activation.patch: fixed upstream.
* Tue Mar  6 2012 dimstar@opensuse.org
- Add glade-sig-activation.patch: Emit a signal to notify signal
  activation. Anjuta 3.3.91 makes use of this signal.
* Wed Feb 15 2012 dimstar@opensuse.org
- Update to version 3.11.0:
  + Features:
  - Added GtkSwitch, GtkInfoBar and GtkEntryCompletion support.
  - Implemented inline margins and alignment edit mode.
  + Major changes:
  - Ignore GtkWindow:icon property (bgo#654121)
  - Port to pygobject 3 (bgo#658667)
  - Make GladeProject change gtk target to 3.0 and warn the user
    if there are any unknown (deprecated) objects (bgo#652673,
    bgo#376628)
  + Other changes:
  - Optimized loading time.
  - Update placeholders when a grid child's width or height child
    properties change.
  - Bug fixes, including: bgo#646997, bgo#647984, bgo#648487,
    bgo#650899, bgo#651673, bgo#654609, bgo#657164, bgo#660607,
    bgo#660872, bgo#660874.
  + Updated translations.
- Drop glade-pygobject-3.0.patch: fixed upstream.
- Drop glade-explicit-gmodule.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  as we no longer carry any patches.
* Wed Dec 21 2011 vuntz@opensuse.org
- Add glade-explicit-gmodule.patch: explicitly link to
  gmodule-2.0, to fix build with latest glib.
- Split typelib files into typelib-1_0-Gladeui-2_0 subpackage.
- Add typelib-1_0-Gladeui-2_0 Requires to devel subpackage.
* Wed Oct 12 2011 vuntz@opensuse.org
- Update to version 3.10.2:
  + Optimized loading time by not updating progressbar on every
    loaded object.
  + Update placeholders when a grid child's width or height child
    properties change.
  + Ensure 'related-action' and 'use-action-appearance' are
    serialized in the right order.
  + Correctly detect the required devhelp version.
  + Make documentation parallel installable (bgo#646997).
  + Renamed catalog and module environment variables.
  + Properly escape special characters while serializing property
    values (bgo#654609).
  + Fixed size groups widget selection (bgo#647984).
  + Avoid crashing if glade-previewer is not installed
    (bgo#650899).
  + Fixed loading correct application icon (bgo#648487).
  + Fixed "variable set but not used" warnings.
  + Other bugs fixed: bgo#651673, bgo#657164, bgo#660607,
    bgo#660872, bgo#660874.
  + Updated translations.
* Fri Sep 30 2011 vuntz@opensuse.org
- Port to pygobject 3.0:
  + Add glade-pygobject-3.0.patch: taken from git.
  + Change pkgconfig(pygobject-2.0) BuildRequires to
    pkgconfig(pygobject-3.0).
  + Add gnome-common BuildRequires and call to gnome-autogen.sh,
    needed for the patch.
* Tue May  3 2011 vuntz@opensuse.org
- New package, based on the glade3 package: the GTK+ 3 version of
  glade has been renamed back to glade (without glade3, yes, it's
  confusing).
